You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2018/09/20 16:45:23 UTC

svn commit: r1841481 - in /subversion/trunk/subversion: include/private/svn_client_private.h include/svn_client.h libsvn_client/diff.c libsvn_client/layout.c libsvn_client/shelf.c libsvn_client/status.c svn/info-cmd.c svn/shelf-cmd.c

Author: julianfoad
Date: Thu Sep 20 16:45:22 2018
New Revision: 1841481

URL: http://svn.apache.org/viewvc?rev=1841481&view=rev
Log:
Move all experimental APIs to the private namespace.

Part of issue SVN-4775 "Add x- prefix to experimental APIs".

* subversion/include/svn_client.h
  (svn_client__layout_func_t): Renamed from 'svn_client_layout_func_t'.
  (svn_client__layout_list): Renamed from 'svn_client_layout_list'.
  (svn_client_shelf_*): Rename to 'svn_client__shelf_*'.

* subversion/include/private/svn_client_private.h
  (svn_client__shelf_diff): Track the renames.

* subversion/libsvn_client/diff.c
  (diff_shelf): Track the renames.

* subversion/libsvn_client/layout.c
  (client_layout_baton_t,
   svn_client__layout_list): Track the renames.

* subversion/libsvn_client/shelf.c
  Track the renames.

* subversion/libsvn_client/status.c
  (shelf_status): Track the renames.

* subversion/svn/info-cmd.c
  Track the renames.

* subversion/svn/shelf-cmd.c
  Track the renames.

Modified:
    subversion/trunk/subversion/include/private/svn_client_private.h
    subversion/trunk/subversion/include/svn_client.h
    subversion/trunk/subversion/libsvn_client/diff.c
    subversion/trunk/subversion/libsvn_client/layout.c
    subversion/trunk/subversion/libsvn_client/shelf.c
    subversion/trunk/subversion/libsvn_client/status.c
    subversion/trunk/subversion/svn/info-cmd.c
    subversion/trunk/subversion/svn/shelf-cmd.c

Modified: subversion/trunk/subversion/include/private/svn_client_private.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/private/svn_client_private.h?rev=1841481&r1=1841480&r2=1841481&view=diff
==============================================================================
--- subversion/trunk/subversion/include/private/svn_client_private.h (original)
+++ subversion/trunk/subversion/include/private/svn_client_private.h Thu Sep 20 16:45:22 2018
@@ -383,7 +383,7 @@ svn_client__get_diff_writer_svn(
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client__shelf_diff(svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_diff(svn_client__shelf_version_t *shelf_version,
                        const char *shelf_relpath,
                        svn_depth_t depth,
                        svn_boolean_t ignore_ancestry,

Modified: subversion/trunk/subversion/include/svn_client.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_client.h?rev=1841481&r1=1841480&r2=1841481&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_client.h (original)
+++ subversion/trunk/subversion/include/svn_client.h Thu Sep 20 16:45:22 2018
@@ -1547,11 +1547,11 @@ svn_client_switch(svn_revnum_t *result_r
 
 /** @} */
 
-/** Callback for svn_client_layout_list()
+/** Callback for svn_client__layout_list()
  *
  * @warning EXPERIMENTAL.
  */
-typedef svn_error_t * (*svn_client_layout_func_t)(
+typedef svn_error_t * (*svn_client__layout_func_t)(
                             void *layout_baton,
                             const char *local_abspath,
                             const char *repos_root_url,
@@ -1572,11 +1572,11 @@ typedef svn_error_t * (*svn_client_layou
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_layout_list(const char *local_abspath,
-                       svn_client_layout_func_t layout,
-                       void *layout_baton,
-                       svn_client_ctx_t *ctx,
-                       apr_pool_t *scratch_pool);
+svn_client__layout_list(const char *local_abspath,
+                        svn_client__layout_func_t layout,
+                        void *layout_baton,
+                        svn_client_ctx_t *ctx,
+                        apr_pool_t *scratch_pool);
 
 
 /**
@@ -6938,7 +6938,7 @@ svn_client_cat(svn_stream_t *out,
  * @since New in 1.X.
  * @warning EXPERIMENTAL.
  */
-typedef struct svn_client_shelf_t
+typedef struct svn_client__shelf_t
 {
     /* Public fields (read-only for public use) */
     const char *name;
@@ -6950,23 +6950,23 @@ typedef struct svn_client_shelf_t
     apr_hash_t *revprops;  /**< non-null; allocated in POOL */
     svn_client_ctx_t *ctx;
     apr_pool_t *pool;
-} svn_client_shelf_t;
+} svn_client__shelf_t;
 
 /** One version of a shelved change-set.
  *
  * @since New in 1.X.
  * @warning EXPERIMENTAL.
  */
-typedef struct svn_client_shelf_version_t
+typedef struct svn_client__shelf_version_t
 {
   /* Public fields (read-only for public use) */
-  svn_client_shelf_t *shelf;
+  svn_client__shelf_t *shelf;
   apr_time_t mtime;  /**< time-stamp of this version */
 
   /* Private fields */
   const char *files_dir_abspath;  /**< abspath of the storage area */
   int version_number;  /**< version number starting from 1 */
-} svn_client_shelf_version_t;
+} svn_client__shelf_version_t;
 
 /** Open an existing shelf or create a new shelf.
  *
@@ -6982,7 +6982,7 @@ typedef struct svn_client_shelf_version_
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_open_or_create(svn_client_shelf_t **shelf_p,
+svn_client__shelf_open_or_create(svn_client__shelf_t **shelf_p,
                                 const char *name,
                                 const char *local_abspath,
                                 svn_client_ctx_t *ctx,
@@ -6999,7 +6999,7 @@ svn_client_shelf_open_or_create(svn_clie
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_open_existing(svn_client_shelf_t **shelf_p,
+svn_client__shelf_open_existing(svn_client__shelf_t **shelf_p,
                                const char *name,
                                const char *local_abspath,
                                svn_client_ctx_t *ctx,
@@ -7014,7 +7014,7 @@ svn_client_shelf_open_existing(svn_clien
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_close(svn_client_shelf_t *shelf,
+svn_client__shelf_close(svn_client__shelf_t *shelf,
                        apr_pool_t *scratch_pool);
 
 /** Delete the shelf named @a name, or error if it doesn't exist.
@@ -7026,7 +7026,7 @@ svn_client_shelf_close(svn_client_shelf_
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_delete(const char *name,
+svn_client__shelf_delete(const char *name,
                         const char *local_abspath,
                         svn_boolean_t dry_run,
                         svn_client_ctx_t *ctx,
@@ -7057,8 +7057,8 @@ svn_client_shelf_delete(const char *name
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_save_new_version3(svn_client_shelf_version_t **new_version_p,
-                                   svn_client_shelf_t *shelf,
+svn_client__shelf_save_new_version3(svn_client__shelf_version_t **new_version_p,
+                                   svn_client__shelf_t *shelf,
                                    const apr_array_header_t *paths,
                                    svn_depth_t depth,
                                    const apr_array_header_t *changelists,
@@ -7085,8 +7085,8 @@ svn_client_shelf_save_new_version3(svn_c
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_delete_newer_versions(svn_client_shelf_t *shelf,
-                                       svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_delete_newer_versions(svn_client__shelf_t *shelf,
+                                       svn_client__shelf_version_t *shelf_version,
                                        apr_pool_t *scratch_pool);
 
 /** Return in @a shelf_version an existing version of @a shelf, given its
@@ -7099,8 +7099,8 @@ svn_client_shelf_delete_newer_versions(s
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_version_open(svn_client_shelf_version_t **shelf_version_p,
-                              svn_client_shelf_t *shelf,
+svn_client__shelf_version_open(svn_client__shelf_version_t **shelf_version_p,
+                              svn_client__shelf_t *shelf,
                               int version_number,
                               apr_pool_t *result_pool,
                               apr_pool_t *scratch_pool);
@@ -7114,8 +7114,8 @@ svn_client_shelf_version_open(svn_client
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_get_newest_version(svn_client_shelf_version_t **shelf_version_p,
-                                    svn_client_shelf_t *shelf,
+svn_client__shelf_get_newest_version(svn_client__shelf_version_t **shelf_version_p,
+                                    svn_client__shelf_t *shelf,
                                     apr_pool_t *result_pool,
                                     apr_pool_t *scratch_pool);
 
@@ -7129,8 +7129,8 @@ svn_client_shelf_get_newest_version(svn_
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_get_all_versions(apr_array_header_t **versions_p,
-                                  svn_client_shelf_t *shelf,
+svn_client__shelf_get_all_versions(apr_array_header_t **versions_p,
+                                  svn_client__shelf_t *shelf,
                                   apr_pool_t *result_pool,
                                   apr_pool_t *scratch_pool);
 
@@ -7145,7 +7145,7 @@ svn_client_shelf_get_all_versions(apr_ar
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_apply(svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_apply(svn_client__shelf_version_t *shelf_version,
                        svn_boolean_t dry_run,
                        apr_pool_t *scratch_pool);
 
@@ -7177,8 +7177,8 @@ svn_client_shelf_apply(svn_client_shelf_
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_test_apply_file(svn_boolean_t *conflict_p,
-                                 svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_test_apply_file(svn_boolean_t *conflict_p,
+                                 svn_client__shelf_version_t *shelf_version,
                                  const char *file_relpath,
                                  apr_pool_t *scratch_pool);
 
@@ -7189,7 +7189,7 @@ svn_client_shelf_test_apply_file(svn_boo
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_unapply(svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_unapply(svn_client__shelf_version_t *shelf_version,
                          svn_boolean_t dry_run,
                          apr_pool_t *scratch_pool);
 
@@ -7206,8 +7206,8 @@ svn_client_shelf_unapply(svn_client_shel
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_paths_changed(apr_hash_t **affected_paths,
-                               svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_paths_changed(apr_hash_t **affected_paths,
+                               svn_client__shelf_version_t *shelf_version,
                                apr_pool_t *result_pool,
                                apr_pool_t *scratch_pool);
 
@@ -7223,7 +7223,7 @@ svn_client_shelf_paths_changed(apr_hash_
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_revprop_set(svn_client_shelf_t *shelf,
+svn_client__shelf_revprop_set(svn_client__shelf_t *shelf,
                              const char *prop_name,
                              const svn_string_t *prop_val,
                              apr_pool_t *scratch_pool);
@@ -7237,7 +7237,7 @@ svn_client_shelf_revprop_set(svn_client_
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_revprop_set_all(svn_client_shelf_t *shelf,
+svn_client__shelf_revprop_set_all(svn_client__shelf_t *shelf,
                                  apr_hash_t *revprop_table,
                                  apr_pool_t *scratch_pool);
 
@@ -7256,8 +7256,8 @@ svn_client_shelf_revprop_set_all(svn_cli
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_revprop_get(svn_string_t **prop_val,
-                             svn_client_shelf_t *shelf,
+svn_client__shelf_revprop_get(svn_string_t **prop_val,
+                             svn_client__shelf_t *shelf,
                              const char *prop_name,
                              apr_pool_t *result_pool);
 
@@ -7271,8 +7271,8 @@ svn_client_shelf_revprop_get(svn_string_
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_revprop_list(apr_hash_t **props,
-                              svn_client_shelf_t *shelf,
+svn_client__shelf_revprop_list(apr_hash_t **props,
+                              svn_client__shelf_t *shelf,
                               apr_pool_t *result_pool);
 
 /** Set the log message in @a shelf to @a log_message.
@@ -7286,7 +7286,7 @@ svn_client_shelf_revprop_list(apr_hash_t
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_set_log_message(svn_client_shelf_t *shelf,
+svn_client__shelf_set_log_message(svn_client__shelf_t *shelf,
                                  const char *log_message,
                                  apr_pool_t *scratch_pool);
 
@@ -7303,8 +7303,8 @@ svn_client_shelf_set_log_message(svn_cli
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_get_log_message(char **log_message,
-                                 svn_client_shelf_t *shelf,
+svn_client__shelf_get_log_message(char **log_message,
+                                 svn_client__shelf_t *shelf,
                                  apr_pool_t *result_pool);
 
 /** Information about a shelf.
@@ -7312,10 +7312,10 @@ svn_client_shelf_get_log_message(char **
  * @since New in 1.X.
  * @warning EXPERIMENTAL.
  */
-typedef struct svn_client_shelf_info_t
+typedef struct svn_client__shelf_info_t
 {
   apr_time_t mtime;  /**< mtime of the latest change */
-} svn_client_shelf_info_t;
+} svn_client__shelf_info_t;
 
 /** Set @a *shelf_infos to a hash, keyed by shelf name, of pointers to
  * @c svn_client_shelf_info_t structures, one for each shelf in the
@@ -7328,7 +7328,7 @@ typedef struct svn_client_shelf_info_t
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_list(apr_hash_t **shelf_infos,
+svn_client__shelf_list(apr_hash_t **shelf_infos,
                       const char *local_abspath,
                       svn_client_ctx_t *ctx,
                       apr_pool_t *result_pool,
@@ -7342,7 +7342,7 @@ svn_client_shelf_list(apr_hash_t **shelf
  */
 SVN_EXPERIMENTAL
 svn_error_t *
-svn_client_shelf_version_status_walk(svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_version_status_walk(svn_client__shelf_version_t *shelf_version,
                                      const char *wc_relpath,
                                      svn_wc_status_func4_t walk_func,
                                      void *walk_baton,

Modified: subversion/trunk/subversion/libsvn_client/diff.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/diff.c?rev=1841481&r1=1841480&r2=1841481&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/diff.c (original)
+++ subversion/trunk/subversion/libsvn_client/diff.c Thu Sep 20 16:45:22 2018
@@ -2354,11 +2354,11 @@ diff_shelf(const char *shelf_name,
            apr_pool_t *scratch_pool)
 {
   svn_error_t *err;
-  svn_client_shelf_t *shelf;
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_t *shelf;
+  svn_client__shelf_version_t *shelf_version;
   const char *wc_relpath;
 
-  err = svn_client_shelf_open_existing(&shelf,
+  err = svn_client__shelf_open_existing(&shelf,
                                        shelf_name, target_abspath,
                                        ctx, scratch_pool);
   if (err && err->apr_err == SVN_ERR_ILLEGAL_TARGET)
@@ -2369,14 +2369,14 @@ diff_shelf(const char *shelf_name,
   else
     SVN_ERR(err);
 
-  SVN_ERR(svn_client_shelf_version_open(&shelf_version,
+  SVN_ERR(svn_client__shelf_version_open(&shelf_version,
                                         shelf, shelf->max_version,
                                         scratch_pool, scratch_pool));
   wc_relpath = svn_dirent_skip_ancestor(shelf->wc_root_abspath, target_abspath);
   SVN_ERR(svn_client__shelf_diff(shelf_version, wc_relpath,
                                  depth, ignore_ancestry,
                                  diff_processor, scratch_pool));
-  SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+  SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
 
   return SVN_NO_ERROR;
 }

Modified: subversion/trunk/subversion/libsvn_client/layout.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/layout.c?rev=1841481&r1=1841480&r2=1841481&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/layout.c (original)
+++ subversion/trunk/subversion/libsvn_client/layout.c Thu Sep 20 16:45:22 2018
@@ -58,7 +58,7 @@ struct client_layout_baton_t
   struct layout_item_t *stack;
   apr_pool_t *root_pool;
 
-  svn_client_layout_func_t layout;
+  svn_client__layout_func_t layout;
   void *layout_baton;
 };
 
@@ -256,11 +256,11 @@ static const svn_ra_reporter3_t layout_r
 };
 
 svn_error_t *
-svn_client_layout_list(const char *local_abspath,
-                       svn_client_layout_func_t layout,
-                       void *layout_baton,
-                       svn_client_ctx_t *ctx,
-                       apr_pool_t *scratch_pool)
+svn_client__layout_list(const char *local_abspath,
+                        svn_client__layout_func_t layout,
+                        void *layout_baton,
+                        svn_client_ctx_t *ctx,
+                        apr_pool_t *scratch_pool)
 {
   struct client_layout_baton_t lb;
 

Modified: subversion/trunk/subversion/libsvn_client/shelf.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/shelf.c?rev=1841481&r1=1841480&r2=1841481&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/shelf.c (original)
+++ subversion/trunk/subversion/libsvn_client/shelf.c Thu Sep 20 16:45:22 2018
@@ -119,7 +119,7 @@ shelf_name_from_filename(char **name,
  */
 static svn_error_t *
 shelf_version_files_dir_abspath(const char **abspath,
-                                svn_client_shelf_t *shelf,
+                                svn_client__shelf_t *shelf,
                                 int version,
                                 apr_pool_t *result_pool,
                                 apr_pool_t *scratch_pool)
@@ -137,12 +137,12 @@ shelf_version_files_dir_abspath(const ch
  * exist on disk.
  */
 static svn_error_t *
-shelf_version_create(svn_client_shelf_version_t **new_version_p,
-                     svn_client_shelf_t *shelf,
+shelf_version_create(svn_client__shelf_version_t **new_version_p,
+                     svn_client__shelf_t *shelf,
                      int version_number,
                      apr_pool_t *result_pool)
 {
-  svn_client_shelf_version_t *shelf_version
+  svn_client__shelf_version_t *shelf_version
     = apr_pcalloc(result_pool, sizeof(*shelf_version));
 
   shelf_version->shelf = shelf;
@@ -159,7 +159,7 @@ shelf_version_create(svn_client_shelf_ve
  */
 static svn_error_t *
 get_metadata_abspath(char **abspath,
-                     svn_client_shelf_version_t *shelf_version,
+                     svn_client__shelf_version_t *shelf_version,
                      const char *wc_relpath,
                      apr_pool_t *result_pool,
                      apr_pool_t *scratch_pool)
@@ -175,7 +175,7 @@ get_metadata_abspath(char **abspath,
  */
 static svn_error_t *
 get_base_file_abspath(char **base_abspath,
-                      svn_client_shelf_version_t *shelf_version,
+                      svn_client__shelf_version_t *shelf_version,
                       const char *wc_relpath,
                       apr_pool_t *result_pool,
                       apr_pool_t *scratch_pool)
@@ -191,7 +191,7 @@ get_base_file_abspath(char **base_abspat
  */
 static svn_error_t *
 get_working_file_abspath(char **work_abspath,
-                         svn_client_shelf_version_t *shelf_version,
+                         svn_client__shelf_version_t *shelf_version,
                          const char *wc_relpath,
                          apr_pool_t *result_pool,
                          apr_pool_t *scratch_pool)
@@ -207,7 +207,7 @@ get_working_file_abspath(char **work_abs
  */
 static svn_error_t *
 get_base_props_abspath(char **base_abspath,
-                       svn_client_shelf_version_t *shelf_version,
+                       svn_client__shelf_version_t *shelf_version,
                        const char *wc_relpath,
                        apr_pool_t *result_pool,
                        apr_pool_t *scratch_pool)
@@ -223,7 +223,7 @@ get_base_props_abspath(char **base_abspa
  */
 static svn_error_t *
 get_working_props_abspath(char **work_abspath,
-                          svn_client_shelf_version_t *shelf_version,
+                          svn_client__shelf_version_t *shelf_version,
                           const char *wc_relpath,
                           apr_pool_t *result_pool,
                           apr_pool_t *scratch_pool)
@@ -236,7 +236,7 @@ get_working_props_abspath(char **work_ab
 
 /* Delete the storage for SHELF:VERSION. */
 static svn_error_t *
-shelf_version_delete(svn_client_shelf_t *shelf,
+shelf_version_delete(svn_client__shelf_t *shelf,
                      int version,
                      apr_pool_t *scratch_pool)
 {
@@ -254,7 +254,7 @@ shelf_version_delete(svn_client_shelf_t
 /*  */
 static svn_error_t *
 get_log_abspath(char **log_abspath,
-                svn_client_shelf_t *shelf,
+                svn_client__shelf_t *shelf,
                 apr_pool_t *result_pool,
                 apr_pool_t *scratch_pool)
 {
@@ -272,7 +272,7 @@ get_log_abspath(char **log_abspath,
  * is not an error.
  */
 static svn_error_t *
-shelf_read_revprops(svn_client_shelf_t *shelf,
+shelf_read_revprops(svn_client__shelf_t *shelf,
                     apr_pool_t *scratch_pool)
 {
   char *log_abspath;
@@ -299,7 +299,7 @@ shelf_read_revprops(svn_client_shelf_t *
 /* Write SHELF's revprops to its file storage.
  */
 static svn_error_t *
-shelf_write_revprops(svn_client_shelf_t *shelf,
+shelf_write_revprops(svn_client__shelf_t *shelf,
                      apr_pool_t *scratch_pool)
 {
   char *log_abspath;
@@ -319,7 +319,7 @@ shelf_write_revprops(svn_client_shelf_t
 }
 
 svn_error_t *
-svn_client_shelf_revprop_set(svn_client_shelf_t *shelf,
+svn_client__shelf_revprop_set(svn_client__shelf_t *shelf,
                              const char *prop_name,
                              const svn_string_t *prop_val,
                              apr_pool_t *scratch_pool)
@@ -331,7 +331,7 @@ svn_client_shelf_revprop_set(svn_client_
 }
 
 svn_error_t *
-svn_client_shelf_revprop_set_all(svn_client_shelf_t *shelf,
+svn_client__shelf_revprop_set_all(svn_client__shelf_t *shelf,
                                  apr_hash_t *revprop_table,
                                  apr_pool_t *scratch_pool)
 {
@@ -345,8 +345,8 @@ svn_client_shelf_revprop_set_all(svn_cli
 }
 
 svn_error_t *
-svn_client_shelf_revprop_get(svn_string_t **prop_val,
-                             svn_client_shelf_t *shelf,
+svn_client__shelf_revprop_get(svn_string_t **prop_val,
+                             svn_client__shelf_t *shelf,
                              const char *prop_name,
                              apr_pool_t *result_pool)
 {
@@ -355,8 +355,8 @@ svn_client_shelf_revprop_get(svn_string_
 }
 
 svn_error_t *
-svn_client_shelf_revprop_list(apr_hash_t **props,
-                              svn_client_shelf_t *shelf,
+svn_client__shelf_revprop_list(apr_hash_t **props,
+                              svn_client__shelf_t *shelf,
                               apr_pool_t *result_pool)
 {
   *props = shelf->revprops;
@@ -366,7 +366,7 @@ svn_client_shelf_revprop_list(apr_hash_t
 /*  */
 static svn_error_t *
 get_current_abspath(char **current_abspath,
-                    svn_client_shelf_t *shelf,
+                    svn_client__shelf_t *shelf,
                     apr_pool_t *result_pool)
 {
   char *codename;
@@ -382,7 +382,7 @@ get_current_abspath(char **current_abspa
  * Set SHELF->max_version to -1 if that file does not exist.
  */
 static svn_error_t *
-shelf_read_current(svn_client_shelf_t *shelf,
+shelf_read_current(svn_client__shelf_t *shelf,
                    apr_pool_t *scratch_pool)
 {
   char *current_abspath;
@@ -402,7 +402,7 @@ shelf_read_current(svn_client_shelf_t *s
 
 /*  */
 static svn_error_t *
-shelf_write_current(svn_client_shelf_t *shelf,
+shelf_write_current(svn_client__shelf_t *shelf,
                     apr_pool_t *scratch_pool)
 {
   char *current_abspath;
@@ -546,7 +546,7 @@ wc_status_unserialize(svn_wc_status3_t *
 /* Write status to shelf storage.
  */
 static svn_error_t *
-status_write(svn_client_shelf_version_t *shelf_version,
+status_write(svn_client__shelf_version_t *shelf_version,
              const char *relpath,
              const svn_wc_status3_t *status,
              apr_pool_t *scratch_pool)
@@ -567,7 +567,7 @@ status_write(svn_client_shelf_version_t
  */
 static svn_error_t *
 status_read(svn_wc_status3_t **status,
-            svn_client_shelf_version_t *shelf_version,
+            svn_client__shelf_version_t *shelf_version,
             const char *relpath,
             apr_pool_t *result_pool,
             apr_pool_t *scratch_pool)
@@ -601,7 +601,7 @@ typedef svn_error_t *(*shelf_status_visi
 /* Baton for shelved_files_walk_visitor(). */
 struct shelf_status_baton_t
 {
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_version_t *shelf_version;
   const char *top_relpath;
   const char *walk_root_abspath;
   shelf_status_visitor_t walk_func;
@@ -641,7 +641,7 @@ shelf_status_visitor(void *baton,
  * via WALK_FUNC(WALK_BATON, ...).
  */
 static svn_error_t *
-shelf_status_visit_path(svn_client_shelf_version_t *shelf_version,
+shelf_status_visit_path(svn_client__shelf_version_t *shelf_version,
                         const char *wc_relpath,
                         shelf_status_visitor_t walk_func,
                         void *walk_baton,
@@ -667,7 +667,7 @@ shelf_status_visit_path(svn_client_shelf
  * via WALK_FUNC(WALK_BATON, ...).
  */
 static svn_error_t *
-shelf_status_walk(svn_client_shelf_version_t *shelf_version,
+shelf_status_walk(svn_client__shelf_version_t *shelf_version,
                   const char *wc_relpath,
                   shelf_status_visitor_t walk_func,
                   void *walk_baton,
@@ -694,7 +694,7 @@ shelf_status_walk(svn_client_shelf_versi
 
 typedef struct wc_status_baton_t
 {
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_version_t *shelf_version;
   svn_wc_status_func4_t walk_func;
   void *walk_baton;
 } wc_status_baton_t;
@@ -706,7 +706,7 @@ wc_status_visitor(void *baton,
                       apr_pool_t *scratch_pool)
 {
   struct wc_status_baton_t *b = baton;
-  svn_client_shelf_t *shelf = b->shelf_version->shelf;
+  svn_client__shelf_t *shelf = b->shelf_version->shelf;
   const char *abspath = svn_dirent_join(shelf->wc_root_abspath, relpath,
                                         scratch_pool);
   SVN_ERR(b->walk_func(b->walk_baton, abspath, status, scratch_pool));
@@ -714,7 +714,7 @@ wc_status_visitor(void *baton,
 }
 
 svn_error_t *
-svn_client_shelf_version_status_walk(svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_version_status_walk(svn_client__shelf_version_t *shelf_version,
                                      const char *wc_relpath,
                                      svn_wc_status_func4_t walk_func,
                                      void *walk_baton,
@@ -737,7 +737,7 @@ svn_client_shelf_version_status_walk(svn
 /* A baton for use with write_changes_visitor(). */
 typedef struct write_changes_baton_t {
   const char *wc_root_abspath;
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_version_t *shelf_version;
   svn_client_ctx_t *ctx;
   svn_boolean_t any_shelved;  /* were any paths successfully shelved? */
   svn_client_status_func_t was_shelved_func;
@@ -820,7 +820,7 @@ read_props_from_wc(apr_hash_t **base_pro
 /* Write BASE_PROPS and WORK_PROPS to storage in SHELF_VERSION:WC_RELPATH.
  */
 static svn_error_t *
-write_props_to_shelf(svn_client_shelf_version_t *shelf_version,
+write_props_to_shelf(svn_client__shelf_version_t *shelf_version,
                      const char *wc_relpath,
                      apr_hash_t *base_props,
                      apr_hash_t *work_props,
@@ -860,7 +860,7 @@ static svn_error_t *
 read_props_from_shelf(apr_hash_t **base_props,
                       apr_hash_t **work_props,
                       enum svn_wc_status_kind node_status,
-                      svn_client_shelf_version_t *shelf_version,
+                      svn_client__shelf_version_t *shelf_version,
                       const char *wc_relpath,
                       apr_pool_t *result_pool,
                       apr_pool_t *scratch_pool)
@@ -907,7 +907,7 @@ read_props_from_shelf(apr_hash_t **base_
 static svn_error_t *
 store_file(const char *from_wc_abspath,
            const char *wc_relpath,
-           svn_client_shelf_version_t *shelf_version,
+           svn_client__shelf_version_t *shelf_version,
            const svn_wc_status3_t *status,
            svn_client_ctx_t *ctx,
            apr_pool_t *scratch_pool)
@@ -1125,7 +1125,7 @@ wc_walk_status_multi(const apr_array_hea
  */
 static svn_error_t *
 shelf_write_changes(svn_boolean_t *any_shelved,
-                    svn_client_shelf_version_t *shelf_version,
+                    svn_client__shelf_version_t *shelf_version,
                     const apr_array_header_t *paths,
                     svn_depth_t depth,
                     const apr_array_header_t *changelists,
@@ -1163,13 +1163,13 @@ shelf_write_changes(svn_boolean_t *any_s
  * no revprops, no looking to see if such a shelf exists on disk.
  */
 static svn_error_t *
-shelf_construct(svn_client_shelf_t **shelf_p,
+shelf_construct(svn_client__shelf_t **shelf_p,
                 const char *name,
                 const char *local_abspath,
                 svn_client_ctx_t *ctx,
                 apr_pool_t *result_pool)
 {
-  svn_client_shelf_t *shelf = apr_palloc(result_pool, sizeof(*shelf));
+  svn_client__shelf_t *shelf = apr_palloc(result_pool, sizeof(*shelf));
   char *shelves_dir;
 
   SVN_ERR(svn_client_get_wc_root(&shelf->wc_root_abspath,
@@ -1191,7 +1191,7 @@ shelf_construct(svn_client_shelf_t **she
 }
 
 svn_error_t *
-svn_client_shelf_open_existing(svn_client_shelf_t **shelf_p,
+svn_client__shelf_open_existing(svn_client__shelf_t **shelf_p,
                                const char *name,
                                const char *local_abspath,
                                svn_client_ctx_t *ctx,
@@ -1211,13 +1211,13 @@ svn_client_shelf_open_existing(svn_clien
 }
 
 svn_error_t *
-svn_client_shelf_open_or_create(svn_client_shelf_t **shelf_p,
+svn_client__shelf_open_or_create(svn_client__shelf_t **shelf_p,
                                 const char *name,
                                 const char *local_abspath,
                                 svn_client_ctx_t *ctx,
                                 apr_pool_t *result_pool)
 {
-  svn_client_shelf_t *shelf;
+  svn_client__shelf_t *shelf;
 
   SVN_ERR(shelf_construct(&shelf, name,
                           local_abspath, ctx, result_pool));
@@ -1233,24 +1233,24 @@ svn_client_shelf_open_or_create(svn_clie
 }
 
 svn_error_t *
-svn_client_shelf_close(svn_client_shelf_t *shelf,
+svn_client__shelf_close(svn_client__shelf_t *shelf,
                        apr_pool_t *scratch_pool)
 {
   return SVN_NO_ERROR;
 }
 
 svn_error_t *
-svn_client_shelf_delete(const char *name,
+svn_client__shelf_delete(const char *name,
                         const char *local_abspath,
                         svn_boolean_t dry_run,
                         svn_client_ctx_t *ctx,
                         apr_pool_t *scratch_pool)
 {
-  svn_client_shelf_t *shelf;
+  svn_client__shelf_t *shelf;
   int i;
   char *abspath;
 
-  SVN_ERR(svn_client_shelf_open_existing(&shelf, name,
+  SVN_ERR(svn_client__shelf_open_existing(&shelf, name,
                                          local_abspath, ctx, scratch_pool));
 
   /* Remove the versions. */
@@ -1265,7 +1265,7 @@ svn_client_shelf_delete(const char *name
   SVN_ERR(get_current_abspath(&abspath, shelf, scratch_pool));
   SVN_ERR(svn_io_remove_file2(abspath, TRUE /*ignore_enoent*/, scratch_pool));
 
-  SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+  SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
   return SVN_NO_ERROR;
 }
 
@@ -1301,12 +1301,12 @@ paths_changed_visitor(void *baton,
 static svn_error_t *
 shelf_paths_changed(apr_hash_t **paths_hash_p,
                     apr_array_header_t **paths_array_p,
-                    svn_client_shelf_version_t *shelf_version,
+                    svn_client__shelf_version_t *shelf_version,
                     svn_boolean_t as_abspath,
                     apr_pool_t *result_pool,
                     apr_pool_t *scratch_pool)
 {
-  svn_client_shelf_t *shelf = shelf_version->shelf;
+  svn_client__shelf_t *shelf = shelf_version->shelf;
   apr_hash_t *paths_hash = apr_hash_make(result_pool);
   struct paths_changed_walk_baton_t baton;
 
@@ -1327,8 +1327,8 @@ shelf_paths_changed(apr_hash_t **paths_h
 }
 
 svn_error_t *
-svn_client_shelf_paths_changed(apr_hash_t **affected_paths,
-                               svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_paths_changed(apr_hash_t **affected_paths,
+                               svn_client__shelf_version_t *shelf_version,
                                apr_pool_t *result_pool,
                                apr_pool_t *scratch_pool)
 {
@@ -1482,7 +1482,7 @@ wc_node_add(const char *to_wc_abspath,
 /* Baton for apply_file_visitor(). */
 struct apply_files_baton_t
 {
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_version_t *shelf_version;
   svn_boolean_t test_only;  /* only check whether it would conflict */
   svn_boolean_t conflict;  /* would it conflict? */
   svn_client_ctx_t *ctx;
@@ -1620,7 +1620,7 @@ apply_file_visitor(void *baton,
 
 /*  */
 static svn_error_t *
-file_changed(svn_client_shelf_version_t *shelf_version,
+file_changed(svn_client__shelf_version_t *shelf_version,
              const char *relpath,
              svn_wc_status3_t *s,
              const svn_diff_tree_processor_t *diff_processor,
@@ -1663,7 +1663,7 @@ file_changed(svn_client_shelf_version_t
 
 /*  */
 static svn_error_t *
-file_deleted(svn_client_shelf_version_t *shelf_version,
+file_deleted(svn_client__shelf_version_t *shelf_version,
              const char *relpath,
              svn_wc_status3_t *s,
              const svn_diff_tree_processor_t *diff_processor,
@@ -1699,7 +1699,7 @@ file_deleted(svn_client_shelf_version_t
 
 /*  */
 static svn_error_t *
-file_added(svn_client_shelf_version_t *shelf_version,
+file_added(svn_client__shelf_version_t *shelf_version,
            const char *relpath,
            svn_wc_status3_t *s,
            const svn_diff_tree_processor_t *diff_processor,
@@ -1736,7 +1736,7 @@ file_added(svn_client_shelf_version_t *s
 /* Baton for diff_visitor(). */
 struct diff_baton_t
 {
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_version_t *shelf_version;
   const char *top_relpath;  /* top of diff, relative to shelf */
   const char *walk_root_abspath;
   const svn_diff_tree_processor_t *diff_processor;
@@ -1817,8 +1817,8 @@ diff_visitor(void *baton,
 }
 
 svn_error_t *
-svn_client_shelf_test_apply_file(svn_boolean_t *conflict_p,
-                                 svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_test_apply_file(svn_boolean_t *conflict_p,
+                                 svn_client__shelf_version_t *shelf_version,
                                  const char *file_relpath,
                                  apr_pool_t *scratch_pool)
 {
@@ -1837,7 +1837,7 @@ svn_client_shelf_test_apply_file(svn_boo
 }
 
 svn_error_t *
-svn_client_shelf_apply(svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_apply(svn_client__shelf_version_t *shelf_version,
                        svn_boolean_t dry_run,
                        apr_pool_t *scratch_pool)
 {
@@ -1855,7 +1855,7 @@ svn_client_shelf_apply(svn_client_shelf_
 }
 
 svn_error_t *
-svn_client_shelf_unapply(svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_unapply(svn_client__shelf_version_t *shelf_version,
                          svn_boolean_t dry_run,
                          apr_pool_t *scratch_pool)
 {
@@ -1877,8 +1877,8 @@ svn_client_shelf_unapply(svn_client_shel
 }
 
 svn_error_t *
-svn_client_shelf_delete_newer_versions(svn_client_shelf_t *shelf,
-                                       svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_delete_newer_versions(svn_client__shelf_t *shelf,
+                                       svn_client__shelf_version_t *shelf_version,
                                        apr_pool_t *scratch_pool)
 {
   int previous_version = shelf_version ? shelf_version->version_number : 0;
@@ -1896,7 +1896,7 @@ svn_client_shelf_delete_newer_versions(s
 }
 
 svn_error_t *
-svn_client__shelf_diff(svn_client_shelf_version_t *shelf_version,
+svn_client__shelf_diff(svn_client__shelf_version_t *shelf_version,
                        const char *shelf_relpath,
                        svn_depth_t depth,
                        svn_boolean_t ignore_ancestry,
@@ -1920,8 +1920,8 @@ svn_client__shelf_diff(svn_client_shelf_
 }
 
 svn_error_t *
-svn_client_shelf_save_new_version3(svn_client_shelf_version_t **new_version_p,
-                                   svn_client_shelf_t *shelf,
+svn_client__shelf_save_new_version3(svn_client__shelf_version_t **new_version_p,
+                                   svn_client__shelf_t *shelf,
                                    const apr_array_header_t *paths,
                                    svn_depth_t depth,
                                    const apr_array_header_t *changelists,
@@ -1932,7 +1932,7 @@ svn_client_shelf_save_new_version3(svn_c
                                    apr_pool_t *scratch_pool)
 {
   int next_version = shelf->max_version + 1;
-  svn_client_shelf_version_t *new_shelf_version;
+  svn_client__shelf_version_t *new_shelf_version;
   svn_boolean_t any_shelved;
 
   SVN_ERR(shelf_version_create(&new_shelf_version,
@@ -1951,7 +1951,7 @@ svn_client_shelf_save_new_version3(svn_c
       SVN_ERR(shelf_write_current(shelf, scratch_pool));
 
       if (new_version_p)
-        SVN_ERR(svn_client_shelf_version_open(new_version_p, shelf, next_version,
+        SVN_ERR(svn_client__shelf_version_open(new_version_p, shelf, next_version,
                                               scratch_pool, scratch_pool));
     }
   else
@@ -1963,8 +1963,8 @@ svn_client_shelf_save_new_version3(svn_c
 }
 
 svn_error_t *
-svn_client_shelf_get_log_message(char **log_message,
-                                 svn_client_shelf_t *shelf,
+svn_client__shelf_get_log_message(char **log_message,
+                                 svn_client__shelf_t *shelf,
                                  apr_pool_t *result_pool)
 {
   svn_string_t *propval = svn_hash_gets(shelf->revprops, SVN_PROP_REVISION_LOG);
@@ -1977,20 +1977,20 @@ svn_client_shelf_get_log_message(char **
 }
 
 svn_error_t *
-svn_client_shelf_set_log_message(svn_client_shelf_t *shelf,
+svn_client__shelf_set_log_message(svn_client__shelf_t *shelf,
                                  const char *message,
                                  apr_pool_t *scratch_pool)
 {
   svn_string_t *propval
     = message ? svn_string_create(message, shelf->pool) : NULL;
 
-  SVN_ERR(svn_client_shelf_revprop_set(shelf, SVN_PROP_REVISION_LOG, propval,
+  SVN_ERR(svn_client__shelf_revprop_set(shelf, SVN_PROP_REVISION_LOG, propval,
                                        scratch_pool));
   return SVN_NO_ERROR;
 }
 
 svn_error_t *
-svn_client_shelf_list(apr_hash_t **shelf_infos,
+svn_client__shelf_list(apr_hash_t **shelf_infos,
                       const char *local_abspath,
                       svn_client_ctx_t *ctx,
                       apr_pool_t *result_pool,
@@ -2020,7 +2020,7 @@ svn_client_shelf_list(apr_hash_t **shelf
       svn_error_clear(shelf_name_from_filename(&name, filename, result_pool));
       if (name && dirent->kind == svn_node_file)
         {
-          svn_client_shelf_info_t *info
+          svn_client__shelf_info_t *info
             = apr_palloc(result_pool, sizeof(*info));
 
           info->mtime = dirent->mtime;
@@ -2032,13 +2032,13 @@ svn_client_shelf_list(apr_hash_t **shelf
 }
 
 svn_error_t *
-svn_client_shelf_version_open(svn_client_shelf_version_t **shelf_version_p,
-                              svn_client_shelf_t *shelf,
+svn_client__shelf_version_open(svn_client__shelf_version_t **shelf_version_p,
+                              svn_client__shelf_t *shelf,
                               int version_number,
                               apr_pool_t *result_pool,
                               apr_pool_t *scratch_pool)
 {
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_version_t *shelf_version;
   const svn_io_dirent2_t *dirent;
 
   SVN_ERR(shelf_version_create(&shelf_version,
@@ -2060,8 +2060,8 @@ svn_client_shelf_version_open(svn_client
 }
 
 svn_error_t *
-svn_client_shelf_get_newest_version(svn_client_shelf_version_t **shelf_version_p,
-                                    svn_client_shelf_t *shelf,
+svn_client__shelf_get_newest_version(svn_client__shelf_version_t **shelf_version_p,
+                                    svn_client__shelf_t *shelf,
                                     apr_pool_t *result_pool,
                                     apr_pool_t *scratch_pool)
 {
@@ -2071,31 +2071,31 @@ svn_client_shelf_get_newest_version(svn_
       return SVN_NO_ERROR;
     }
 
-  SVN_ERR(svn_client_shelf_version_open(shelf_version_p,
+  SVN_ERR(svn_client__shelf_version_open(shelf_version_p,
                                         shelf, shelf->max_version,
                                         result_pool, scratch_pool));
   return SVN_NO_ERROR;
 }
 
 svn_error_t *
-svn_client_shelf_get_all_versions(apr_array_header_t **versions_p,
-                                  svn_client_shelf_t *shelf,
+svn_client__shelf_get_all_versions(apr_array_header_t **versions_p,
+                                  svn_client__shelf_t *shelf,
                                   apr_pool_t *result_pool,
                                   apr_pool_t *scratch_pool)
 {
   int i;
 
   *versions_p = apr_array_make(result_pool, shelf->max_version - 1,
-                               sizeof(svn_client_shelf_version_t *));
+                               sizeof(svn_client__shelf_version_t *));
 
   for (i = 1; i <= shelf->max_version; i++)
     {
-      svn_client_shelf_version_t *shelf_version;
+      svn_client__shelf_version_t *shelf_version;
 
-      SVN_ERR(svn_client_shelf_version_open(&shelf_version,
+      SVN_ERR(svn_client__shelf_version_open(&shelf_version,
                                             shelf, i,
                                             result_pool, scratch_pool));
-      APR_ARRAY_PUSH(*versions_p, svn_client_shelf_version_t *) = shelf_version;
+      APR_ARRAY_PUSH(*versions_p, svn_client__shelf_version_t *) = shelf_version;
     }
   return SVN_NO_ERROR;
 }

Modified: subversion/trunk/subversion/libsvn_client/status.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/status.c?rev=1841481&r1=1841480&r2=1841481&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/status.c (original)
+++ subversion/trunk/subversion/libsvn_client/status.c Thu Sep 20 16:45:22 2018
@@ -344,11 +344,11 @@ shelf_status(const char *shelf_name,
              apr_pool_t *scratch_pool)
 {
   svn_error_t *err;
-  svn_client_shelf_t *shelf;
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_t *shelf;
+  svn_client__shelf_version_t *shelf_version;
   const char *wc_relpath;
 
-  err = svn_client_shelf_open_existing(&shelf,
+  err = svn_client__shelf_open_existing(&shelf,
                                        shelf_name, target_abspath,
                                        ctx, scratch_pool);
   if (err && err->apr_err == SVN_ERR_ILLEGAL_TARGET)
@@ -359,14 +359,14 @@ shelf_status(const char *shelf_name,
   else
     SVN_ERR(err);
 
-  SVN_ERR(svn_client_shelf_version_open(&shelf_version,
+  SVN_ERR(svn_client__shelf_version_open(&shelf_version,
                                         shelf, shelf->max_version,
                                         scratch_pool, scratch_pool));
   wc_relpath = svn_dirent_skip_ancestor(shelf->wc_root_abspath, target_abspath);
-  SVN_ERR(svn_client_shelf_version_status_walk(shelf_version, wc_relpath,
+  SVN_ERR(svn_client__shelf_version_status_walk(shelf_version, wc_relpath,
                                                status_func, status_baton,
                                                scratch_pool));
-  SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+  SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
 
   return SVN_NO_ERROR;
 }

Modified: subversion/trunk/subversion/svn/info-cmd.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/info-cmd.c?rev=1841481&r1=1841480&r2=1841481&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/shelf-cmd.c (original)
+++ subversion/trunk/subversion/svn/shelf-cmd.c Thu Sep 20 16:45:22 2018
@@ -43,12 +43,12 @@
 
 /* Open the newest version of SHELF; error if no versions found. */
 static svn_error_t *
-get_newest_version_existing(svn_client_shelf_version_t **shelf_version_p,
-                            svn_client_shelf_t *shelf,
+get_newest_version_existing(svn_client__shelf_version_t **shelf_version_p,
+                            svn_client__shelf_t *shelf,
                             apr_pool_t *result_pool,
                             apr_pool_t *scratch_pool)
 {
-  SVN_ERR(svn_client_shelf_get_newest_version(shelf_version_p, shelf,
+  SVN_ERR(svn_client__shelf_get_newest_version(shelf_version_p, shelf,
                                               result_pool, scratch_pool));
   if (!*shelf_version_p)
     {
@@ -183,8 +183,8 @@ static int
 compare_shelf_infos_by_mtime(const svn_sort__item_t *a,
                              const svn_sort__item_t *b)
 {
-  svn_client_shelf_info_t *a_val = a->value;
-  svn_client_shelf_info_t *b_val = b->value;
+  svn_client__shelf_info_t *a_val = a->value;
+  svn_client__shelf_info_t *b_val = b->value;
 
   return (a_val->mtime < b_val->mtime)
     ? -1 : (a_val->mtime > b_val->mtime) ? 1 : 0;
@@ -200,7 +200,7 @@ list_sorted_by_date(apr_array_header_t *
 {
   apr_hash_t *shelf_infos;
 
-  SVN_ERR(svn_client_shelf_list(&shelf_infos, local_abspath,
+  SVN_ERR(svn_client__shelf_list(&shelf_infos, local_abspath,
                                 ctx, scratch_pool, scratch_pool));
   *list = svn_sort__hash(shelf_infos,
                          compare_shelf_infos_by_mtime,
@@ -210,9 +210,9 @@ list_sorted_by_date(apr_array_header_t *
 
 /*  */
 static svn_error_t *
-stats(svn_client_shelf_t *shelf,
+stats(svn_client__shelf_t *shelf,
       int version,
-      svn_client_shelf_version_t *shelf_version,
+      svn_client__shelf_version_t *shelf_version,
       apr_time_t time_now,
       svn_boolean_t with_logmsg,
       apr_pool_t *scratch_pool)
@@ -236,7 +236,7 @@ stats(svn_client_shelf_t *shelf,
                                Q_("version %d of %d", "version %d of %d",
                                   shelf->max_version),
                                version, shelf->max_version);
-  SVN_ERR(svn_client_shelf_paths_changed(&paths, shelf_version,
+  SVN_ERR(svn_client__shelf_paths_changed(&paths, shelf_version,
                                          scratch_pool, scratch_pool));
   paths_str = apr_psprintf(scratch_pool,
                            Q_("%d path changed", "%d paths changed",
@@ -250,7 +250,7 @@ stats(svn_client_shelf_t *shelf,
     {
       char *log_message;
 
-      SVN_ERR(svn_client_shelf_get_log_message(&log_message, shelf,
+      SVN_ERR(svn_client__shelf_get_log_message(&log_message, shelf,
                                                scratch_pool));
       if (log_message)
         {
@@ -281,12 +281,12 @@ shelves_list(const char *local_abspath,
     {
       const svn_sort__item_t *item = &APR_ARRAY_IDX(list, i, svn_sort__item_t);
       const char *name = item->key;
-      svn_client_shelf_t *shelf;
-      svn_client_shelf_version_t *shelf_version;
+      svn_client__shelf_t *shelf;
+      svn_client__shelf_version_t *shelf_version;
 
-      SVN_ERR(svn_client_shelf_open_existing(&shelf, name, local_abspath,
+      SVN_ERR(svn_client__shelf_open_existing(&shelf, name, local_abspath,
                                              ctx, scratch_pool));
-      SVN_ERR(svn_client_shelf_get_newest_version(&shelf_version, shelf,
+      SVN_ERR(svn_client__shelf_get_newest_version(&shelf_version, shelf,
                                                   scratch_pool, scratch_pool));
       if (quiet)
         SVN_ERR(svn_cmdline_printf(scratch_pool, "%s\n", shelf->name));
@@ -296,7 +296,7 @@ shelves_list(const char *local_abspath,
       else
         SVN_ERR(stats(shelf, shelf->max_version, shelf_version, time_now,
                       TRUE /*with_logmsg*/, scratch_pool));
-      SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+      SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
     }
 
   return SVN_NO_ERROR;
@@ -311,24 +311,24 @@ shelf_log(const char *name,
           apr_pool_t *scratch_pool)
 {
   apr_time_t time_now = apr_time_now();
-  svn_client_shelf_t *shelf;
+  svn_client__shelf_t *shelf;
   apr_array_header_t *versions;
   int i;
 
-  SVN_ERR(svn_client_shelf_open_existing(&shelf, name, local_abspath,
+  SVN_ERR(svn_client__shelf_open_existing(&shelf, name, local_abspath,
                                          ctx, scratch_pool));
-  SVN_ERR(svn_client_shelf_get_all_versions(&versions, shelf,
+  SVN_ERR(svn_client__shelf_get_all_versions(&versions, shelf,
                                             scratch_pool, scratch_pool));
   for (i = 0; i < versions->nelts; i++)
     {
-      svn_client_shelf_version_t *shelf_version
+      svn_client__shelf_version_t *shelf_version
         = APR_ARRAY_IDX(versions, i, void *);
 
       SVN_ERR(stats(shelf, i + 1, shelf_version, time_now,
                     FALSE /*with_logmsg*/, scratch_pool));
     }
 
-  SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+  SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
   return SVN_NO_ERROR;
 }
 
@@ -450,15 +450,15 @@ shelve(int *new_version_p,
        svn_client_ctx_t *ctx,
        apr_pool_t *scratch_pool)
 {
-  svn_client_shelf_t *shelf;
-  svn_client_shelf_version_t *previous_version;
-  svn_client_shelf_version_t *new_version;
+  svn_client__shelf_t *shelf;
+  svn_client__shelf_version_t *previous_version;
+  svn_client__shelf_version_t *new_version;
   struct status_baton sb;
 
-  SVN_ERR(svn_client_shelf_open_or_create(&shelf,
+  SVN_ERR(svn_client__shelf_open_or_create(&shelf,
                                           name, local_abspath,
                                           ctx, scratch_pool));
-  SVN_ERR(svn_client_shelf_get_newest_version(&previous_version, shelf,
+  SVN_ERR(svn_client__shelf_get_newest_version(&previous_version, shelf,
                                               scratch_pool, scratch_pool));
 
   if (! quiet)
@@ -482,16 +482,16 @@ shelve(int *new_version_p,
     SVN_ERR(svn_cmdline_printf(scratch_pool,
                                keep_local ? _("--- Saving...\n")
                                : _("--- Shelving...\n")));
-  SVN_ERR(svn_client_shelf_save_new_version3(&new_version, shelf,
+  SVN_ERR(svn_client__shelf_save_new_version3(&new_version, shelf,
                                              paths, depth, changelists,
                                              was_shelved, &sb,
                                              was_not_shelved, &sb,
                                              scratch_pool));
   if (sb.num_paths_not_shelved > 0)
     {
-      SVN_ERR(svn_client_shelf_delete_newer_versions(shelf, previous_version,
+      SVN_ERR(svn_client__shelf_delete_newer_versions(shelf, previous_version,
                                                      scratch_pool));
-      SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+      SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
       return svn_error_createf(SVN_ERR_ILLEGAL_TARGET, NULL,
                                Q_("%d path could not be shelved",
                                   "%d paths could not be shelved",
@@ -501,7 +501,7 @@ shelve(int *new_version_p,
   if (sb.num_paths_shelved == 0
       || ! new_version)
     {
-      SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+      SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
       return svn_error_createf(SVN_ERR_ILLEGAL_TARGET, NULL,
                                keep_local ? _("No local modifications could be saved")
                                : _("No local modifications could be shelved"));
@@ -510,7 +510,7 @@ shelve(int *new_version_p,
   /* Un-apply the changes, if required. */
   if (!keep_local)
     {
-      SVN_ERR(svn_client_shelf_unapply(new_version,
+      SVN_ERR(svn_client__shelf_unapply(new_version,
                                        dry_run, scratch_pool));
     }
 
@@ -538,18 +538,18 @@ shelve(int *new_version_p,
         }
     }
 
-  SVN_ERR(svn_client_shelf_revprop_set_all(shelf, revprop_table, scratch_pool));
+  SVN_ERR(svn_client__shelf_revprop_set_all(shelf, revprop_table, scratch_pool));
 
   if (new_version_p)
     *new_version_p = shelf->max_version;
 
   if (dry_run)
     {
-      SVN_ERR(svn_client_shelf_delete_newer_versions(shelf, previous_version,
+      SVN_ERR(svn_client__shelf_delete_newer_versions(shelf, previous_version,
                                                      scratch_pool));
     }
 
-  SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+  SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
   return SVN_NO_ERROR;
 }
 
@@ -582,21 +582,21 @@ status_to_char(enum svn_wc_status_kind s
 /* Throw an error if any path affected by SHELF_VERSION gives a conflict
  * when applied (as a dry-run) to the WC. */
 static svn_error_t *
-test_apply(svn_client_shelf_version_t *shelf_version,
+test_apply(svn_client__shelf_version_t *shelf_version,
            svn_client_ctx_t *ctx,
            apr_pool_t *scratch_pool)
 {
   apr_hash_t *paths;
   apr_hash_index_t *hi;
 
-  SVN_ERR(svn_client_shelf_paths_changed(&paths, shelf_version,
+  SVN_ERR(svn_client__shelf_paths_changed(&paths, shelf_version,
                                          scratch_pool, scratch_pool));
   for (hi = apr_hash_first(scratch_pool, paths); hi; hi = apr_hash_next(hi))
     {
       const char *path = apr_hash_this_key(hi);
       svn_boolean_t conflict;
 
-      SVN_ERR(svn_client_shelf_test_apply_file(&conflict, shelf_version, path,
+      SVN_ERR(svn_client__shelf_test_apply_file(&conflict, shelf_version, path,
                                                scratch_pool));
       if (conflict)
         {
@@ -637,17 +637,17 @@ shelf_restore(const char *name,
 {
   int version, old_version;
   apr_time_t time_now = apr_time_now();
-  svn_client_shelf_t *shelf;
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_t *shelf;
+  svn_client__shelf_version_t *shelf_version;
 
-  SVN_ERR(svn_client_shelf_open_existing(&shelf, name, local_abspath,
+  SVN_ERR(svn_client__shelf_open_existing(&shelf, name, local_abspath,
                                          ctx, scratch_pool));
 
   old_version = shelf->max_version;
   if (arg)
     {
       SVN_ERR(svn_cstring_atoi(&version, arg));
-      SVN_ERR(svn_client_shelf_version_open(&shelf_version,
+      SVN_ERR(svn_client__shelf_version_open(&shelf_version,
                                             shelf, version,
                                             scratch_pool, scratch_pool));
     }
@@ -674,12 +674,12 @@ shelf_restore(const char *name,
                   "or other status in the working copy"));
     }
 
-  SVN_ERR(svn_client_shelf_apply(shelf_version,
+  SVN_ERR(svn_client__shelf_apply(shelf_version,
                                  dry_run, scratch_pool));
 
   if (! dry_run)
     {
-      SVN_ERR(svn_client_shelf_delete_newer_versions(shelf, shelf_version,
+      SVN_ERR(svn_client__shelf_delete_newer_versions(shelf, shelf_version,
                                                      scratch_pool));
     }
 
@@ -697,7 +697,7 @@ shelf_restore(const char *name,
                                    name, version));
     }
 
-  SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+  SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
   return SVN_NO_ERROR;
 }
 
@@ -711,12 +711,12 @@ shelf_diff(const char *name,
            svn_client_ctx_t *ctx,
            apr_pool_t *scratch_pool)
 {
-  svn_client_shelf_t *shelf;
-  svn_client_shelf_version_t *shelf_version;
+  svn_client__shelf_t *shelf;
+  svn_client__shelf_version_t *shelf_version;
   svn_stream_t *stream, *errstream;
   svn_diff_tree_processor_t *diff_processor;
 
-  SVN_ERR(svn_client_shelf_open_existing(&shelf, name, local_abspath,
+  SVN_ERR(svn_client__shelf_open_existing(&shelf, name, local_abspath,
                                          ctx, scratch_pool));
 
   if (arg)
@@ -724,7 +724,7 @@ shelf_diff(const char *name,
       int version;
 
       SVN_ERR(svn_cstring_atoi(&version, arg));
-      SVN_ERR(svn_client_shelf_version_open(&shelf_version,
+      SVN_ERR(svn_client__shelf_version_open(&shelf_version,
                                             shelf, version,
                                             scratch_pool, scratch_pool));
     }
@@ -777,7 +777,7 @@ shelf_diff(const char *name,
                                  diff_processor, scratch_pool));
   SVN_ERR(svn_stream_close(stream));
 
-  SVN_ERR(svn_client_shelf_close(shelf, scratch_pool));
+  SVN_ERR(svn_client__shelf_close(shelf, scratch_pool));
   return SVN_NO_ERROR;
 }
 
@@ -790,7 +790,7 @@ shelf_drop(const char *name,
            svn_client_ctx_t *ctx,
            apr_pool_t *scratch_pool)
 {
-  SVN_ERR(svn_client_shelf_delete(name, local_abspath, dry_run,
+  SVN_ERR(svn_client__shelf_delete(name, local_abspath, dry_run,
                                   ctx, scratch_pool));
   if (! quiet)
     SVN_ERR(svn_cmdline_printf(scratch_pool,
@@ -1029,21 +1029,21 @@ shelf_list_by_paths(apr_array_header_t *
     {
       svn_sort__item_t *item = &APR_ARRAY_IDX(shelves, i, svn_sort__item_t);
       const char *name = item->key;
-      svn_client_shelf_t *shelf;
-      svn_client_shelf_version_t *shelf_version;
+      svn_client__shelf_t *shelf;
+      svn_client__shelf_version_t *shelf_version;
       apr_hash_t *shelf_paths;
       int j;
 
-      SVN_ERR(svn_client_shelf_open_existing(&shelf,
-                                             name, wc_root_abspath,
-                                             ctx, scratch_pool));
-      SVN_ERR(svn_client_shelf_get_newest_version(&shelf_version, shelf,
-                                                  scratch_pool, scratch_pool));
+      SVN_ERR(svn_client__shelf_open_existing(&shelf,
+                                              name, wc_root_abspath,
+                                              ctx, scratch_pool));
+      SVN_ERR(svn_client__shelf_get_newest_version(&shelf_version, shelf,
+                                                   scratch_pool, scratch_pool));
       if (!shelf_version)
         continue;
-      SVN_ERR(svn_client_shelf_paths_changed(&shelf_paths,
-                                             shelf_version,
-                                             scratch_pool, scratch_pool));
+      SVN_ERR(svn_client__shelf_paths_changed(&shelf_paths,
+                                              shelf_version,
+                                              scratch_pool, scratch_pool));
       for (j = 0; j < target_relpaths->nelts; j++)
         {
           char *target_relpath = APR_ARRAY_IDX(target_relpaths, j, char *);
--- subversion/trunk/subversion/svn/info-cmd.c (original)
+++ subversion/trunk/subversion/svn/info-cmd.c Thu Sep 20 16:45:22 2018
@@ -60,7 +60,7 @@ struct layout_list_baton_t
 
 /* Output as 'svn' command-line commands.
  *
- * Implements svn_client_layout_func_t
+ * Implements svn_client__layout_func_t
  */
 static svn_error_t *
 output_svn_command_line(void *layout_baton,
@@ -163,7 +163,7 @@ depth_to_viewspec_py(svn_depth_t depth,
 
 /* Output in the format used by 'tools/client-side/viewspec.py'
  *
- * Implements svn_client_layout_func_t
+ * Implements svn_client__layout_func_t
  */
 static svn_error_t *
 output_svn_viewspec_py(void *layout_baton,
@@ -243,7 +243,7 @@ output_svn_viewspec_py(void *layout_bato
 }
 
 /*
  * Call svn_client_layout_list(), using a receiver function decided
  * by VIEWSPEC.
  */
 static svn_error_t *
@@ -280,15 +280,15 @@ cl_layout_list(apr_array_header_t *targe
       /* svn-viewspec.py format */
       llb.vs_py_format = 2;
 
-      SVN_ERR(svn_client_layout_list(list_abspath,
-                                     output_svn_viewspec_py, &llb,
-                                     ctx, scratch_pool));
+      SVN_ERR(svn_client__layout_list(list_abspath,
+                                      output_svn_viewspec_py, &llb,
+                                      ctx, scratch_pool));
       break;
     case svn_cl__viewspec_svn11:
       /* svn command-line format */
-      SVN_ERR(svn_client_layout_list(list_abspath,
-                                     output_svn_command_line, &llb,
-                                     ctx, scratch_pool));
+      SVN_ERR(svn_client__layout_list(list_abspath,
+                                      output_svn_command_line, &llb,
+                                      ctx, scratch_pool));
       break;
     default:
       SVN_ERR_MALFUNCTION();
@@ -243,7 +243,7 @@ output_svn_viewspec_py(void *layout_bato
 
 /*
- * Call svn_client_layout_list(), using a receiver function decided
+ * Call svn_client__layout_list(), using a receiver function decided
  * by VIEWSPEC.
  */

Modified: subversion/trunk/subversion/svn/shelf-cmd.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/shelf-cmd.c?rev=1841481&r1=1841480&r2=1841481&view=diff
==============================================================================